"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("@merl/util");
const SHORTNAME_REGEX = /^\w+\/\w+$/i;
/**
 * Clones the given git repository into the given directory, within the given
 * working directory.
 */
async function clone(repoName, cwd, { destination, host } = {}) {
    if (repoName.match(SHORTNAME_REGEX) !== null) {
        host = host || 'github.com';
        repoName = `git@${host}:${repoName}.git`;
    }
    if (destination) {
        await util_1.exec(`git clone "${repoName}" "${destination}"`, cwd);
    }
    else {
        await util_1.exec(`git clone "${repoName}"`, cwd);
    }
    return undefined;
}
exports.clone = clone;
/**
 * Check out the given branch
 */
async function checkout(branchName, cwd) {
    await util_1.exec(`git checkout ${branchName}`, cwd);
}
exports.checkout = checkout;
/**
 * Check out a new branch with the given name
 */
async function checkoutNewBranch(branchName, cwd) {
    await util_1.exec(`git checkout -b ${branchName}`, cwd);
}
exports.checkoutNewBranch = checkoutNewBranch;
/**
 * Check if the given git working directory is clean
 */
async function isCleanWorkingDirectory(cwd) {
    const result = await util_1.exec(`git status --porcelain`, cwd);
    return !!result.match(/^\s*$/);
}
exports.isCleanWorkingDirectory = isCleanWorkingDirectory;
/**
 * Update a remote branch with the latest commits in the local branch
 */
async function updateRemoteBranch(branchName, remote, cwd, force = false) {
    return await util_1.exec(`git push ${remote} ${branchName} ${force ? '-f' : ''}`, cwd);
}
exports.updateRemoteBranch = updateRemoteBranch;
async function getRecentBranches(cwd, numberOfBranches = 5) {
    const result = await util_1.exec('git for-each-ref --sort=committerdate refs/heads/', cwd);
    return result
        .split('\n')
        .filter(line => line.length > 0)
        .map(branchRow => {
        return branchRow.match(/^\s*[0-9a-f]+\s+[a-z]+\s+refs\/heads\/(.*)\s*$/i)[1];
    })
        .slice(0, numberOfBranches);
}
exports.getRecentBranches = getRecentBranches;
//# sourceMappingURL=basic.js.map