"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
jest.mock('@merl/util');
const util_1 = require("@merl/util");
const basic_1 = require("./basic");
test('clones a repo', async () => {
    util_1.exec.mockImplementation(() => Promise.resolve());
    await basic_1.clone('git@github.com:chriscasola/merlin.git', 'cwd');
    expect(util_1.exec).toHaveBeenCalledTimes(1);
    expect(util_1.exec).toHaveBeenCalledWith('git clone "git@github.com:chriscasola/merlin.git"', 'cwd');
    await basic_1.clone('https://github.com/chriscasola/merlin.git', 'cwd');
    expect(util_1.exec).toHaveBeenCalledTimes(2);
    expect(util_1.exec).toHaveBeenCalledWith('git clone "https://github.com/chriscasola/merlin.git"', 'cwd');
});
test('clones a repo using the short name', async () => {
    util_1.exec.mockImplementation(() => Promise.resolve());
    await basic_1.clone('chriscasola/merlin', 'cwd');
    expect(util_1.exec).toHaveBeenCalledTimes(1);
    expect(util_1.exec).toHaveBeenCalledWith('git clone "git@github.com:chriscasola/merlin.git"', 'cwd');
});
test('clones a repo into an alternate directory', async () => {
    util_1.exec.mockImplementation(() => Promise.resolve());
    await basic_1.clone('chriscasola/merlin', 'cwd', { destination: 'merlin2' });
    expect(util_1.exec).toHaveBeenCalledTimes(1);
    expect(util_1.exec).toHaveBeenCalledWith('git clone "git@github.com:chriscasola/merlin.git" "merlin2"', 'cwd');
});
test('clones a repo using a short name and alternate host', async () => {
    util_1.exec.mockImplementation(() => Promise.resolve());
    await basic_1.clone('chriscasola/merlin', 'cwd', {
        destination: 'merlin2',
        host: 'github.mycompany.com',
    });
    expect(util_1.exec).toHaveBeenCalledTimes(1);
    expect(util_1.exec).toHaveBeenCalledWith('git clone "git@github.mycompany.com:chriscasola/merlin.git" "merlin2"', 'cwd');
});
test('check out a branch', async () => {
    util_1.exec.mockImplementation(() => Promise.resolve());
    await basic_1.checkout('feat/my-branch', 'cwd');
    expect(util_1.exec).toHaveBeenCalledTimes(1);
    expect(util_1.exec).toHaveBeenCalledWith('git checkout feat/my-branch', 'cwd');
});
test('check out a new branch', async () => {
    util_1.exec.mockImplementation(() => Promise.resolve());
    await basic_1.checkoutNewBranch('feat/my-branch', 'cwd');
    expect(util_1.exec).toHaveBeenCalledTimes(1);
    expect(util_1.exec).toHaveBeenCalledWith('git checkout -b feat/my-branch', 'cwd');
});
test('check for clean working directory', async () => {
    util_1.exec.mockImplementation(() => Promise.resolve('M bla'));
    const isClean = await basic_1.isCleanWorkingDirectory('cwd');
    expect(util_1.exec).toHaveBeenCalledTimes(1);
    expect(util_1.exec).toHaveBeenCalledWith('git status --porcelain', 'cwd');
    expect(isClean).toBe(false);
    util_1.exec.mockImplementation(() => Promise.resolve(''));
    expect(await basic_1.isCleanWorkingDirectory('cwd')).toBe(true);
    util_1.exec.mockImplementation(() => Promise.resolve(' \n '));
    expect(await basic_1.isCleanWorkingDirectory('cwd')).toBe(true);
});
test('update a remote branch', async () => {
    await basic_1.updateRemoteBranch('feat/my-branch', 'upstream', 'cwd');
    expect(util_1.exec).toHaveBeenCalledTimes(1);
    expect(util_1.exec).toHaveBeenCalledWith('git push upstream feat/my-branch ', 'cwd');
    await basic_1.updateRemoteBranch('feat/my-branch', 'upstream', 'cwd', true);
    expect(util_1.exec).toHaveBeenCalledTimes(2);
    expect(util_1.exec).toHaveBeenCalledWith('git push upstream feat/my-branch -f', 'cwd');
});
test('get recent branches', async () => {
    util_1.exec.mockImplementation(() => Promise.resolve('abcd commit refs/heads/branch1\r\n1234 commit refs/heads/branch2\r\n'));
    let result = await basic_1.getRecentBranches('cwd');
    expect(util_1.exec).toHaveBeenCalledTimes(1);
    expect(result).toEqual(['branch1', 'branch2']);
    result = await basic_1.getRecentBranches('cwd', 1);
    expect(result).toEqual(['branch1']);
});
//# sourceMappingURL=basic.spec.js.map